@@ -22,16 +22,24 @@ from .http import SeleniumBrowserUcRequest
 class SeleniumBrowserUcMiddleware:
     """Scrapy middleware handling the requests using selenium"""
 
-    def __init__(self, driver):
+    def __init__(self, driver, web):
         self.driver = driver
+        self.web = web
 
     @classmethod
     def from_crawler(cls, crawler):
         """Initialize the middleware with the crawler settings"""
-        driver = BrowserV2()
+        driver_headless = crawler.settings.get('SELENIUM_DRIVER_HEADLESS')
+
+        if driver_headless is None:
+            raise NotConfigured('SELENIUM_DRIVER_HEADLESS. E.g. <True> to enable headless mode.')
+
+        web = BrowserV2(use_headless=driver_headless)
+        driver = web.driver
 
         middleware = cls(
-            driver=driver
+            driver=driver,
+            web=web
         )
 
         crawler.signals.connect(middleware.spider_closed, signals.spider_closed)
@@ -68,7 +76,10 @@ class SeleniumBrowserUcMiddleware:
         body = str.encode(self.driver.page_source)
 
         # Expose the driver via the "meta" attribute
-        request.meta.update({'driver': self.driver})
+        request.meta.update({
+            'driver': self.driver,
+            'browser': self.web
+        })
 
         return HtmlResponse(
             self.driver.current_url,
@@ -80,4 +91,4 @@ class SeleniumBrowserUcMiddleware:
     def spider_closed(self):
         """Shutdown the driver when spider is closed"""
 
-        self.driver.close_driver()
+        self.driver.quit()
